%  Adaptive Signal Processing Toolbox Version 2.0   
%  April 2002.
%  Copyright (c) DSP ALGORITHMS, 2000-2002.
%
% Transversal adaptive algorithms :
%   
%   asptarlmsnewt       - AR modeling implementation of LMS-Newton method.
%   asptbfdaf           - Block Frequency Domain Adaptive Filter.
%   asptleakynlms       - Leaky Normalized Least Mean Squares.
%   asptlclms           - Linearly Constrained LMS.
%   asptlms             - Least Mean Squares (LMS) and its variants.
%   asptmvsslms         - Reduced complexity Variable Step Size LMS
%   asptnlms            - Normalized LMS.
%   asptpbfdaf          - Partitioned Block Frequency Domain.
%   asptrcpbfdaf        - Reduced Complexity Partitioned Block Frequency Domain.
%   asptrls             - Recursive Least Squares.
%   aspttdlms           - Transform domain LMS.
%   asptvsslms          - Variable Step Size LMS.
%
% Lattice adaptive algorithms :
%
%   asptlbpef           - Adaptive LMS Lattice Backward Prediction Error Filter.
%   asptlfpef           - Adaptive LMS Lattice Forward Prediction Error Filter.
%   asptlmslattice      - LMS Lattice Joint Process Estimator.
%   asptrlslbpef        - Adaptive RLS Lattice Backward Prediction Error Filter.
%   asptrlslfpef        - Adaptive RLS Lattice Forward Prediction Error Filter.
%   asptrlslattice      - RLS Lattice Joint Process Estimator.
%
% Recursive adaptive algorithms :
%
%   asptcsoiir2         - Cascaded Second Order IIR adaptive filter.
%   aspteqerr           - Equation Error IIR adaptive filter.
%   asptouterr          - Output Error IIR.
%   asptsharf           - Simple Hyperstable Adaptive Recursive Filter.
%   asptsoiir1          - Second Order IIR adaptive algorithm type-1.
%   asptsoiir2          - Second Order IIR adaptive algorithm  type-2.
%
% Specialized adaptive algorithms :
%
%   asptadjlms          - Adjoint LMS.
%   asptfdadj           - Frequency Domain Adjoint LMS.
%   asptfdfxlms         - Frequency Domain Filtered-x LMS.
%   asptfxlms           - Filtered-x LMS.
%   asptmcadjlms        - Multichannel Adjoint LMS.
%   asptmcfdadjlms      - Multichannel Frequency Domain Adjoint LMS.
%   asptmcfdfxlms       - Multichannel Frequency Domain Filtered-x LMS.
%   asptmcfxlms         - Multichannel Filtered-x LMS.
%
% Initialization functions.
%
%   init_adjlms         - Adjoint LMS.
%   init_arlmsnewt      - AR modeling implementation of LMS-Newton method.
%   init_bfdaf          - Block Frequency Domain Adaptive Filter.
%   init_csoiir2        - Cascaded Second Order IIR adaptive filter.
%   init_eqerr          - Equation Error IIR adaptive filter.
%   init_fdadjlms       - Frequency Domain Adjoint LMS.
%   init_fdfxlms        - Frequency Domain Filtered-x LMS.
%   init_fxlms          - Filtered-x LMS.
%   init_lbpef          - Adaptive Lattice Backward Prediction Error Filter.
%   init_lclms          - Linearly Constrained LMS.
%   init_leakynlms      - Leaky Normalized Least Mean Squares.
%   init_lfpef          - Lattice Forward Prediction Error Filter.
%   init_lms            - Least Mean Squares (LMS).
%   init_lmslattice     - LMS Lattice adaptive filter.
%   init_mcadjlms       - Multichannel Adjoint LMS.
%   init_mcfdadjlms     - Multichannel Frequency Domain Adjoint LMS.
%   init_mcfdfxlms      - Multichannel Frequency Domain Filtered-x LMS.
%   init_mcfxlms        - Multichannel Filtered-x LMS.
%   init_mvsslms        - Reduced complexity Variable Step Size LMS.
%   init_nlms           - Normalized LMS.
%   init_outerr         - Output Error IIR.
%   init_pbfdaf         - Partitioned Block Frequency Domain.
%   init_rcpbfdaf       - Reduced Complexity Partitioned Block Frequency Domain.
%   init_rls            - Recursive Least Squares.
%   init_rlslattice     - Recursive Least Squares Lattice filter.
%   init_rlslbpef       - Adaptive RLS Lattice Backward Prediction Error Filter.
%   init_rlslfpef       - Adaptive RLS Lattice Forward Prediction Error Filter.
%   init_sharf          - Simple Hyperstable Adaptive Recursive Filter.
%   init_soiir1         - Second Order IIR adaptive algorithm type-1.
%   init_soiir2         - Second Order IIR adaptive algorithm type-2.
%   init_tdlms          - Transform domain LMS.
%   init_vsslms         - Variable Step Size LMS.
%
% Visualization and help functions
%
%   init_ipwin          - Initializes iteration progress GUI window.
%   ipwin               - Builds the iteration progress GUI window.
%   getStop             - Returns the condition of the stop button in the IPWIN.
%   guifb               - Handles the GUI feedback functions of the IPWIN.
%   mcmixr              - Calculates the response of N speakers at M microphones.
%   plot_ale            - Generates plots for the Adaptive Line Enhancer problems.
%   plot_anvc           - Generates plots for Active Noise and Vibration Control problems.
%   plot_beam           - Generates plots for beam forming problems.
%   plot_echo           - Generates plots for echo cancellers applications.
%   plot_model          - Generates plots for modeling problems.
%   plot_predict        - Generates plots for linear prediction problems.
%   update_ipwin        - Updates the iteration progress GUI window.
%
% Examples and applications.
%
%   ale_csoiir2         - Adaptive Line Enhancer using CSOIIR2.
%   ale_soiir1          - Adaptive Line Enhancer using SOIIR1.
%   ale_soiir2          - Adaptive Line Enhancer using SOIIR2.
%
%   anvc_adjlms         - Active noise and vibration control using ADJLMS.
%   anvc_fdadjlms       - Active noise and vibration control using FDADJLMS.
%   anvc_fdfxlms        - Active noise and vibration control using FDFXLMS.
%   anvc_fxlms          - Active noise and vibration control using FXLMS.
%   anvc_mcadjlms       - Active noise and vibration control using MCADJLMS.
%   anvc_mcfdadjlms     - Active noise and vibration control using MCFDADJLMS.
%   anvc_mcfdfxlms      - Active noise and vibration control using MCFDFXLMS.
%   anvc_mcfxlms        - Active noise and vibration control using MCFXLMS.
%
%   beambb_lclms        - Beam former at base-band frequency using LCLMS.
%   beamrf_lms          - Beam former at RF frequency using LMS.
%
%   echo_bfdaf          - Echo canceller using BFDAF.
%   echo_leakynlms      - Echo canceller using LEAKYNLMS.
%   echo_nlms           - Echo canceller using NLMS.
%   echo_pbfdaf         - Echo canceller using PBFDAF.
%   echo_rcpbfdaf       - Echo canceller using RCPBFDAF.
%
%   equalizer_nlms      - Inverse modeling using NLMS.
%   equalizer_rls       - Inverse modeling using RLS.
%
%   model_arlmsnewt     - Modeling using LMS-NEWTON.
%   model_eqerr         - IIR modeling using EQER. 
%   model_lmslattice    - Modeling using LMSLATTICE.
%   model_mvsslms       - FIR modeling using MVSSLMS.
%   model_outerr        - IIR modeling using OUTERR.
%   model_rls           - FIR modeling using RLS.
%   model_rlslattice    - Modeling using RLSLATTICE.
%   model_sharf         - IIR modeling using SHARF.
%   model_tdlms         - FIR modeling using TDLMS.
%   model_vsslms        - FIR modeling using VSSLMS.
%
%   powerline           - interference cancellation using LMS.
%
%   predict_lbpef       - lattice prediction using LBPEF.
%   predict_lfpef       - lattice prediction using LFPEF.
%   predict_rlslbpef    - lattice prediction using RLSLBPEF.
%   predict_rlslfpef    - lattice prediction using RLSLFPEF.
%  

