% [k,w,b,u,P,y,e]=asptarlmsnewt(k,w,x,b,u,P,d,mu_p,mu_w,maxk)
%
%     Efficient implementation of the LMS-Newton algorithm.
%     ARLMSNEWT uses autoregressive modeling of length M << L
%     where M is the model length and L is the filter length.
%     Assumption: the input x(n) is real and stationary for at 
%     least L samples and L > 2*M
% 	
% Input Parameters [Size]:: 
%     k   : vector of lattice predictor coefficients [Mx1]
%     w   : vector of linear combiner coefficients [Lx1]
%     x   : vector of input samples [Lx1]
%     b   : vector of backward prediction error [Lx1]
%     u   : u = R^(-1)*x calculated recursively [Lx1]
%     P   : vector of last estimated power of b [M+1x1]
%     d   : desired response
%     mu_p: adaptation constant for the predictor coefficients
%     mu_w: adaptation constant for the combiner coefficient
%     maxk: maximum allowed value of abs(k)
%  
% Output parameters::
%     k   : updated lattice predictor coefficients 
%     w   : updated linear combiner coefficients 
%     b   : updated backward prediction error 
%     u   : updated {R^(-1)*x} 
%     P   : updated  power estimate of b
%     y   : linear combiner output
%     e   : error signal [e = d - y]
%
% SEE ALSO INIT_ARLMSNEWT, MODEL_ARLMSNEWT

%       Author : John Garas PhD.
%       Version 2.1, Release October 2002.
%       Copyright (c) DSP ALGORITHMS 2000-2002.

