% [w,x,y,e]=asptblms(x,xn,dn,w,mu,alg)
%
%    Performs filtering and coefficient update using the 
%    Block Least Mean Squares (BLMS) algorithm. 
%    BLMS updates the N filter coefficients once every block 
%    of L samples.
% 	
% Input Parameters [Size]:: 
%  x   : previous input delay line [N x 1]
%  xn  : new block of input samples [L x 1]
%  dn  : new block of desired samples [L x 1]
%  w   : vector of filter coefficients [N x 1]
%  mu  : adaptation constant (step size) [1 x 1]
%  alg : specifies the variety of the lms to use in the 
%        update equation. Must be one of the following: 
%        'lms'     [default] 
%        'slms'  - sign LMS, uses sign(e)
%        'srlms' - signed regressor LMS, uses sign(x)
%        'sslms' - sign-sign LMS, uses sign(e) and sign(x)
%
% Output parameters::
%  w   : updated filter coefficients 
%  x   : updated delay-line of input signal
%  y   : block of filter output samples 
%  e   : block of error samples. 
%
% SEE ALSO INIT_BLMS, ASPTBNLMS, ASPTLMS.

%       Author : John Garas PhD.
%       Version 2.1, Release October 2002.
%       Copyright (c) DSP ALGORITHMS 2000-2002.

