% [y,a,b,u,t,s,p] = asptcsoiir2(xn,u,y,a,b,t,s,p,mu_t,mu_s,t_lim,s_lim)
%
%    Sample per sample filtering and parameters update for a
%    cascade of M Second order type-2 IIR Adaptive Line Enhancers
%    with each stage given by
%
%                 (1-s)( cos(t) - z^(-1) )
%     H(z) = ------------------------------------
%             1 - (1+s) cos(t) z^(-1) + s z^(-2)
%
% Input arguments [Size]:
%    xn    : new input sample
%    u     : last 3 input samples for each stage [3x M+1]
%    y     : last 3 output samples for each stage [3x M]
%    a     : last 3 t gradients for each stage [3x M]
%    b     : last 3 s gradients for each stage [3x M]
%    t     : section center freq. parameter {0 pi} [1 x M]
%    s     : section bandwidth parameter {0 1} [1 x M]
%    p     : estimate of the input signal power [1 x M]
%    mu_t  : adaptation constant for t [1 x M]
%    mu_s  : adaptation constant for s [1 x M]
%    t_lim : [t_min t_max]; min. & max. bounds for t 
%    s_lim : [s_min s_max]; min. & max. bounds for s
%
% Output Parameters:
%    y     : updated output buffer 
%    a     : updated t-gradient buffer 
%    b     : updated s-gradient buffer 
%    u     : updated input/error buffer 
%    t     : updated filter CF parameters
%    s     : updated filter BW parameters 
%    p     : updated input power estimate
%
%SEE ALSO INIT_CSOIIR2, ALE_CSOIIR2, ASPTSOIIR2.

%       Author : John Garas PhD.
%       Version 2.1, Release October 2002.
%       Copyright (c) DSP ALGORITHMS 2000-2002.

