% [w,y,e]= asptdrlms(x,w,d,mu,alg,k)	
%
%    Performs filtering and coefficient update using the 
%    Data Reusing Least Mean Squares (DRLMS) algorithm.
%    DRLMS updates the filter coefficients k times each  
%    iteration using the same input data vector to speed 
%    the convergence process. 
% 	
% Input Parameters [size] :: 
%    x   : vector of input samples [L x 1]
%    w   : vector of filter coefficients w(n-1) [L x 1]
%    d   : desired output d(n) [1 x 1]
%    mu  : adaptation constant
%    alg : specifies the variety of the lms to use in the 
%          update equation. Must be one of the following: 
%          'lms'     [default] 
%          'slms'  - sign LMS, uses sign(e)
%          'srlms' - signed regressor LMS, uses sign(x)
%          'sslms' - sign-sign LMS, uses sign(e) and sign(x)
%    k   : number of data reusing cycles
% Output parameters ::
%    w   : updated filter coefficients w(n)
%    y   : filter output y(n)
%    e   : error signal; e(n) = d(n) - y(n)
%
% SEE ALSO INIT_DRLMS, ASPTLMS, ASPTDRNLMS, ASPTRDRLMS, ASPTRDRNLMS.

%       Author : John Garas PhD.
%       Version 2.1, Release October 2002.
%       Copyright (c) DSP ALGORITHMS 2000-2002.

