%  [u,w,y,e,Px,Pd]=aspteqerr(N,M,u,w,y,x,d,mu,Px,Pd)
%
%    Performs filtering and coefficient update using the 
%    Equation Error Adaptive Recursive Filter  
%    algorithm. The filter transfer function is given by
%                   Y(z)      A(z)      
%           W(z) = ----- = ---------- 
%                   X(z)    1 - B(z) 
%
%    where A(z) = a_0 + a_1 z^(-1) + ... + a_(N-1) z^(-N+1)
%    and   B(z) =       b_1 z^(-1) + ... + b_M z^(-M)
%
% Input arguments:
% ---------------
%    N     : Number of coefficients of A(z)
%    M     : Number of coefficients of B(z)
%    u     : composite input vector
%            [x(n) x(n-1) ... x(n-N+1) d(n) ... d(n-M)]'
%    w     : [a_0 a_1 ... a_(N-1) b_1 ... b_M]'
%    y     : [y(n-1) y(n-2) ... y(n-M)]'
%    x     : new input sample
%    d     : new desired sample
%    mu    : adaptation constant
%    Px    : variance of x(n)
%    Pd    : variance of d(n)
%
% Output Parameters:
% -----------------
%    u,w,y,Px,Py are the updated vectors defined above
%    e     : error signal e(n)
%
% SEE ALSO INIT_EQERR, MODEL_EQERR

%       Author : John Garas PhD.
%       Version 2.1, Release October 2002.
%       Copyright (c) DSP ALGORITHMS 2000-2002.

