% [W,w,x,y,e,p,yF,feF] = asptfdadjlms(NC,W,x,xn,d,yF,feF,S,SE,p,mu,b,c)
%
%     Performs filtering and coefficient update using the 
%     Frequency Domain Adjoint Least Mean Squares (FDADJLMS) algorithm
%     for use in Active Noise & Vibration Control (ANVC) applications.
%
%     BLOCK DIAGRAM      
%                                                d(n)
%                                       ----------->-----.
%                                                        |
%                                        y(n)      ys(n) V 
%         x(n) --->.-------------->[ w ]----->[ s ]---->(+)
%                  |                 ^                   |
%                  |                 |                   |e(n)
%                  |                 |   fe(n)           |
%                  '-------------->[LMS]<-----[ se ]--<--'
%
% Input Parameters [size] :: 
%     NC   : controller length in t-domain
%     W    : frequency domain filter coefficients vector [NB x 1]
%     x    : previous overlap-save input vector [NB x 1]
%     xn   : block of new input samples [NL x 1]
%     d    : block of new primary response [NL x 1]
%     yF   : previous output buffer [NB x 1]
%     feF  : previous filtered error buffer [NB x 1]
%     S    : frequency domain secondary path [NB x 1]
%     SE   : frequency domain estimated secondary path [NB x 1]
%     p    : last estimated power of x(n) in f-domain [NB x 1]
%     mu   : adaptation constant
%     b    : pole of AR filter used in estimating p 
%     c    : if not zero, uses the constrained bfdaf algorithm.
%
% Output parameters ::
%     W    : updated frequency domain filter coefficients vector 
%     w    : updated time domain filter coefficients vector 
%     x    : updated overlap-save input vector
%     y    : controller output block 
%     e    : new error block 
%     p    : updated power estimate of x(n)
%     yF   : updated output buffer 
%     feF  : updated filtered error buffer 
%
% SEE ALSO INIT_FDADJLMS, ANVC_FDADJLMS

%       Author : John Garas PhD.
%       Version 2.1, Release October 2002.
%       Copyright (c) DSP ALGORITHMS 2000-2002.

