% [W,w,x,y,e,p,yF,fxF] = asptfdfxlms(NC,W,x,xn,d,yF,fxF,S,SE,p,mu,b,c)
%
%     Performs filtering and coefficient update using the block processing
%     Frequency Domain Filtered-x Least Mean Squares (FDFXLMS) algorithm
%     for use in Active Noise & Vibration Control (ANVC) applications.
%
%     BLOCK DIAGRAM      
%                                                d(n)
%                                       ----------->-----.
%                                                        |
%                                        y(n)      ys(n) V 
%         x(n) --->.-------------->[ w ]----->[ s ]---->(+)
%                  |                 ^                   |
%                  |                 |                   |
%                  |          fx(n)  |          e(n)     |
%                  '-->[ se ]----->[LMS]<--------<-------'
%    
% Input Parameters :: 
%     NC   : controller length in t-domain
%     W    : frequency domain filter coefficients vector [NB x 1]
%     x    : previous overlap-save input vector [NB x 1]
%     xn   : block of new input samples [NL x 1]
%     d    : block of new primary response [NL x 1]
%     yF   : previous output buffer [NB x 1]
%     fxF  : previous filtered-x buffer [NB x 1]
%     S    : frequency domain secondary path [NB x 1]
%     SE   : frequency domain estimated secondary path [NB x 1]
%     p    : last estimated power of fx(n) [NB x 1]
%     mu   : adaptation constant
%     b    : pole of AR filter used in estimating p 
%     c    : if not zero, uses the constrained bfdaf algorithm.
%
% Output parameters ::
%     W    : updated frequency domain filter coefficients vector 
%     w    : updated time domain filter coefficients vector 
%     x    : updated overlap-save input vector
%     y    : controller output block 
%     e    : new error block 
%     p    : updated estimate of power of fx(n)
%     yF   : updated output buffer 
%     fxF  : updated filtered-x buffer 
%
% SEE ALSO INIT_FDFXLMS, ANVC_FDFXLMS

%       Author : John Garas PhD.
%       Version 2.1, Release October 2002.
%       Copyright (c) DSP ALGORITHMS 2000-2002.

