% [ff,bb,k,cf,b,g,w]=asptftrls(ff,bb,k,cf,b,g,w,a,x,d)
%
%    Performs filtering and coefficient update using the 
%    Fast Transversal Recursive Least Squares (FTRLS) algorithm, 
%    also known as the Fast Transversal Filter (FTF) algorithm.
% 	
% Input Parameters:: 
%    ff  : last autocorrelation of forward prediction error (f)
%    bb  : last autocorrelation of backward prediction error (b)
%    k   : normalized gain vector
%    c   : forward transversal predictor coefficients vector
%    g   : backward transversal predictor coefficients vector
%    w   : transversal linear combiner coefficients vector
%    a   : forgetting factor
%    x   : input samples vector
%    d   : desired response d(n)
%
% Output parameters::
%    ff  : updated autocorrelation of forward prediction error 
%    bb  : updated autocorrelation of backward prediction error 
%    k   : updated normalized gain vector
%    c   : updated forward predictor coefficients vector
%    g   : updated backward predictor coefficients vector
%    w   : updated linear combiner coefficients vector
%    y   : linear combiner output 
%    e   : error signal 
%
% SEE ALSO INI_FTRLS, MODEL_FTRLS, ASPTRLSLATTICE.

%       Author : John Garas PhD.
%       Version 2.1, Release October 2002.
%       Copyright (c) DSP ALGORITHMS 2000-2002.

