% [w,y,e,p,fx] = asptfxlms(w,x,y,s,se,d,fx,p,mu,b)
%
%     Performs filtering and coefficient update using the 
%     Filtered-x Least Mean Squares (FXLMS) Adaptive algorithm
%     for use in Active Noise & Vibration Control (ANVC) applications.
%
%     BLOCK DIAGRAM      
%                                                d(n)
%                                       ----------->-----.
%                                                        |
%                                        y(n)      ys(n) V 
%         x(n) --->.-------------->[ w ]----->[ s ]---->(+)
%                  |                 ^                   |
%                  |                 |                   |
%                  |         fx(n)   |          e(n)     |
%                  '-->[ se ]----->[LMS]<--------<-------'
%                                 
% Input Parameters :: 
%     w  : vector of filter coefficients w(n-1) [L x 1]
%     x  : vector of input samples [x(n) x(n-1) .. x(n-(max(L,M)-1))]
%     y  : vector of filter-output y(n-1) [M x 1]
%     s  : accurate FIR model of the secondary path [M x 1]
%     se : estimated FIR model of the secondary path [N x 1]
%     d  : desired response at sample index n [1 x 1]
%     fx : vector of filtered input signal fx(n-1) [N x 1]
%     p  : last estimated power of x(n) [1 x 1]
%     mu : adaptation constant [1 x 1]
%     b  : pole of Autoregressive filter used in estimating p 
%
% Output parameters ::
%     w  : updated filter coefficients w(n)
%     y  : filter output vector [y(n) y(n-1) .. y(n-M-1)]
%     e  : error sample e(n) = d(n) - ys(n)
%     p  : updated estimate of input vector power
%     fx : updated vector of filtered-x samples fx(n)
%
% SEE ALSO INIT_FXLMS, ANVC_FXLMS, ASPTFDFXLMS, ASPTMCFDFXLMS.

%       Author : John Garas PhD.
%       Version 2.1, Release October 2002.
%       Copyright (c) DSP ALGORITHMS 2000-2002.

