% [w,y,e,p] = asptmcadjlms(w,x,e,y,s,se,d,p,mu,b)
%
%     Performs filtering and coefficient update using the 
%     Multichannel Adjoint Least Mean Squares (MCADJLMS) algorithm
%     for use in Active Noise & Vibration Control (ANVC) applications.
%
%     BLOCK DIAGRAM      
%                                                d(n)
%                                       ----------->-----.
%                                                        |
%            Nref                        y(n)      ys(n) V 
%      x(n) --/--->.-------------->[ w ]--/-->[ s ]---->(+)
%                  |                 ^   Nact            |
%                  |                 |                   |e(n)
%                  |                 |   fe(n)           |
%                  '-------------->[LMS]<-----[ se ]<-/--'
%                                                     Nsens
%
% Input Parameters [size]:: 
%     w     : matrix of filter coefficients w(n-1) [L x Nref x Nact]
%     x     : matrix of input samples x(n) [L+M-1 x Nref]
%     e     : matrix of error signal e(n-1) [N x Nsens]
%     y     : matrix of filter-output y(n-1) [M x Nact]
%     s     : accurate FIR model of the secondary paths [M x Nact x Nsens]
%     se    : estimated FIR model of the secondary paths [N x Nact x Nsens]
%     d     : desired response at sample index n [1 x Nsens]
%     p     : last estimated power of x(n) [1 x Nref]
%     mu    : adaptation constant
%     b     : pole of AR filter used to smooth p 
%
% Output parameters ::
%     w     : updated 3-D matrix of filter coefficients 
%     y     : filter output vector matrix y(n)
%     e     : error matrix e(n)
%     p     : new estimated input vector power
%
% SEE ALSO INIT_MCADJLMS, ANVC_MCADJLMS

%       Author : John Garas PhD.
%       Version 2.1, Release October 2002.
%       Copyright (c) DSP ALGORITHMS 2000-2002.

