% [W,w,x,y,e,p,yF,fxF] = asptmcfdfxlms(NC,W,x,xn,dn,yF,fxF,S,SE,p,mu,b,c)
%
%     Performs filtering and coefficient update using the 
%     Multi Channel Frequency Domain Filtered-x LMS (MCFDFXLMS) algorithm
%     for use in Active Noise & Vibration Control (ANVC) applications.
%
%     BLOCK DIAGRAM      
%                                                d(n)
%                                       ----------->-----.
%                                                        |
%            Nref                        y(n)      ys(n) V 
%      x(n) --/--->.-------------->[ w ]--/-->[ s ]---->(+)
%                  |                 ^   Nact            |
%                  |                 |                   |e(n)
%                  |           fx(n) |                   |
%                  '-----[ se ]--->[LMS]<---------/------'
%                                               Nsens
%
% Input Parameters :: 
%     NC   : controller length in time domain
%     W    : freq. domain filter coefficients matrix [NB x Nref x Nact]
%     x    : previous overlap-save input matrix [NB x Nref]
%     xn   : new input samples block [NL x Nref]
%     dn   : new primary samples block [NL x Nsens]
%     yF   : previous buffer of y(n) [NB x Nact]
%     fxF  : previous buffer of fx(n) [NB x Nact x Nsens*Nref]
%     S    : FIR model of the secondary paths [NB x Nact x Nsens]
%     SE   : estimated FIR model S [NB x Nact x Nsens]
%     p    : last estimated power of fx(n) [NB x Nref x Nsens*Nref]
%     mu   : adaptation constant
%     b    : pole of AR filter used in estimating p 
%     c    : if not zero, uses the constrained BFDAF algorithm.
%
% Output parameters ::
%     W    : updated frequency domain filter coefficients  
%     w    : updated time domain filter coefficients  
%     x    : updated overlap-save input matrix
%     y    : controller output block 
%     e    : new error block 
%     p    : updated estimate of power of fx(n)
%     yF   : updated output buffer 
%     fxF  : updated filtered-x buffer 
%
% SEE ALSO INIT_MCFDFXLMS, ANVC_MCFDFXLMS

%       Author : John Garas PhD.
%       Version 2.1, Release October 2002.
%       Copyright (c) DSP ALGORITHMS 2000-2002.

