% [w,y,e,p,fx] = asptmcfxlms(w,x,y,s,se,d,fx,p,mu,b)
%
%     Performs filtering and coefficient update using the 
%     Multichannel Filtered-X Least Mean Squares (MCFXLMS) algorithm
%     (also known as the Multiple Error Filtered-X LMS (MEFXLMS))
%     for use in Active Noise & Vibration Control (ANVC) applications.
%
%
%     BLOCK DIAGRAM      
%                                                d(n)
%                                       ----------->-----.
%                                                        |
%            Nref                        y(n)      ys(n) V 
%      x(n) --/--->.-------------->[ w ]--/-->[ s ]---->(+)
%                  |                 ^   Nact            |
%                  |                 |                   |e(n)
%                  |           fx(n) |                   |
%                  '-----[ se ]--->[LMS]<---------/------'
%                                               Nsens
%
% Input Parameters [size]:: 
%     w     : matrix of filter coefficients w(n-1), [L x Nref x Nact]
%     x     : matrix of input samples x(n) [max(L,N) x Nref]
%     y     : matrix of filter-outputs y(n-1) [M x Nact]
%     s     : accurate FIR model of the secondary paths [M x Nact x Nsens]
%     se    : estimated FIR model of the secondary paths [N x Nact x Nsens]
%     d     : desired response at sample index n [1 x Nsens]
%     fx    : matrix of filtered input signals fx(n-1) [L x Nact x Nsens*Nref]
%     p     : last estimated power of x(n) [1 x Nref]
%     mu    : adaptation constant
%     b     : pole of AR filter used to smooth p 
%
% Output parameters ::
%     w  : updated filter coefficients w(n)
%     y  : updated filter output vector y(n) 
%     e  : error vector e(n) = d(n) - ys(n) [1 x Nsens ]
%     p  : updated estimate of input vector power
%     fx : updated matrix of filtered-x samples fx(n)
%
% SEE ALSO INIT_MCFXLMS, ANVC_MCFXLMS, ASPTFXLMS, ASPTFDFXLMS, ASPTMCFDFXLMS

%       Author : John Garas PhD.
%       Version 2.1, Release October 2002.
%       Copyright (c) DSP ALGORITHMS 2000-2002.

