% [u,w,c,y,e,Px,Py]=asptouterr(N,M,u,w,c,x,d,mu,Px,Py)
%
%    Performs filtering and coefficient update using the 
%    Output Error Adaptive Recursive Filter  
%    algorithm. The filter transfer function is given by
%                   Y(z)      A(z)      
%           W(z) = ----- = ---------- 
%                   X(z)    1 - B(z) 
%
%    where A(z) = a_0 + a_1 z^(-1) + ... + a_(N-1) z^(-N+1)
%    and   B(z) =       b_1 z^(-1) + ... + b_M z^(-M)
%
% Input arguments:
% ---------------
%     N     : Number of coefficients of A(z)
%     M     : Number of coefficients of B(z)
%     u     : [x(n) ... x(n-N+1) y(n-1) ... y(n-M)]^T
%     w     : [a_0 a_1 ... a_(N-1) b_1 ... b_M]^T
%     c     : [a_0(n) ... a_0(n-N+1) b_1(n) ... b_1(n-M)]^T
%     x     : new input sample
%     d     : new desired sample
%     mu    : adaptation constant vector
%     Px    : variance of x(n)
%     Py    : variance of y(n)
%
% Output Parameters:
% -----------------
%     u,w,c,Px,Py are the updated variables defined above
%     y     : filter output y(n)
%     e     : error signal e(n)
%
% SEE ALSO INIT_OUTERR, MODEL_OUTERR

%       Author : John Garas PhD.
%       Version 2.1, Release October 2002.
%       Copyright (c) DSP ALGORITHMS 2000-2002.

