% [ff,bb,fb,be,cf,b,y,e,kf,kb,c]=asptrlslattice(ff,bb,fb,be,cf,b,a,x,d)
%
%    Performs filtering and coefficient update using the 
%    Recursive Least Squares Lattice Joint Process Estimator
%    using the a posteriori estimation errors.
% 	
% Input Parameters:: 
%    ff  : last autocorrelation of forward prediction error (f)
%    bb  : last autocorrelation of backward prediction error (b)
%    fb  : last cross-correlation of f and b 
%    be  : last cross-correlation of b and e 
%    b   : last backward prediction error vector
%    a   : forgetting factor
%    x   : newest input sample x(n)
%    d   : desired response d(n)
%
% Output parameters::
%    ff  : updated autocorrelation of forward prediction error 
%    bb  : updated autocorrelation of backward prediction error 
%    fb  : updated cross-correlation of f and b 
%    be  : updated cross-correlation of b and e 
%    b   : updated backward prediction error vector
%    y   : linear combiner output 
%    e   : error signal 
%    kf  : updated forward lattice coefficients kf(n)
%    kb  : updated backward lattice coefficients kb(n)
%    c   : updated linear combiner coefficients c(n)
%
% SEE ALSO INI_RLSLATTICE, MODEL_RLSLATTICE, ASPTLMSLATTICE2.

%       Author : John Garas PhD.
%       Version 2.1, Release October 2002.
%       Copyright (c) DSP ALGORITHMS 2000-2002.

