% [ff,bb,cf,b,y,e,kf,kb,c]=asptrlslattice2(ff,bb,kf,kb,c,cf,b,a,x,d)
%
%    Performs filtering and coefficient update using the 
%    Recursive Least Squares Lattice Joint Process Estimator
%    using the a priori estimation errors with error feedback.
% 	
% Input Parameters:: 
%    ff  : last autocorrelation of forward prediction error (f)
%    bb  : last autocorrelation of backward prediction error (b)
%    kf  : last forward lattice coefficients kf(n-1)
%    kb  : last backward lattice coefficients kb(n-1)
%    c   : last linear combiner coefficients c(n-1)
%    b   : last backward a priori prediction error vector
%    a   : forgetting factor
%    x   : newest input sample x(n)
%    d   : desired response d(n)
%
% Output parameters::
%    ff  : updated autocorrelation of forward prediction error 
%    bb  : updated autocorrelation of backward prediction error 
%    b   : updated backward a priori estimation error vector
%    y   : linear combiner output 
%    e   : error signal 
%    kf  : updated forward lattice coefficients kf(n)
%    kb  : updated backward lattice coefficients kb(n)
%    c   : updated linear combiner coefficients c(n)
%
% SEE ALSO INI_RLSLATTICE2, MODEL_RLSLATTICE2, ASPTRLSLATTICE.

%       Author : John Garas PhD.
%       Version 2.1, Release October 2002.
%       Copyright (c) DSP ALGORITHMS 2000-2002.

