% [w,u,y,e,Px,Py] = asptsharf(N,M,w,u,x,d,e,c,mu,Px,Py)
%
%    Performs filtering and coefficient update using the 
%    Simple Hyperstable Adaptive Recursive Filter (SHARF) 
%    algorithm. The filter transfer function is given by
%
%                   Y(z)      A(z)      
%           W(z) = ----- = ---------- 
%                   X(z)    1 - B(z) 
%
%    where A(z) = a_0 + a_1 z^(-1) + ... + a_(N-1) z^(-N+1)
%    and   B(z) =       b_1 z^(-1) + ... + b_M z^(-M)
%
% Input arguments:
%    N     : Number of coefficients of A(z)
%    M     : Number of coefficients of B(z)
%    w     : [a_0 a_1 ... a_(N-1) b_1 ... b_M]'
%    u     : composite delay line
%            [x(n) x(n-1) ... x(n-N) y(n-1) ... y(n-M)]'
%    xn    : new input sample
%    d     : desired signal at sample n
%    e     : [e(n-1) e(n-2) ... e(n-L)]'
%    c     : error smoothing coefficients [c_0 c_1 ... c_L-1]'
%    mu    : adaptation constant vector
%    Px    : previously estimated power of input signal x(n)
%    Py    : previously estimated power of output signal y(n)
%
% Output Parameters:
%    w     : updated adaptive coefficients
%    u     : updated composite delay line
%    y     : filter output y(n)
%    e     : error signal e(n)
%    Px    : updated power of input signal x(n)
%    Py    : updated power of output signal y(n)
%
% SEE ALSO INIT_SHARF, MODEL_SHARF

%       Author : John Garas PhD.
%       Version 2.1, Release October 2002.
%       Copyright (c) DSP ALGORITHMS 2000-2002.

