% [y,a,b,e,w,s] = asptsoiir1(u,y,a,b,e,w,s,mu_w,mu_s,w_lim,s_lim)
%
%     Performs filtering and parameter update for the
%     narrow-band Second Order IIR type-1 adaptive filter.
%     The filter transfer function is given by
%
%                 (1-s)(w - z^(-1))
%     H(z) = -------------------------------
%             1 - (1+s) w z^(-1) + s z^(-2)
%
% Input arguments [Size]:
%     u     : the last 3 input samples [3 x 1]
%     y     : the last 3 output samples [3 x 1]
%     a     : the last 3 w gradients [3 x 1]
%     b     : the last 3 s gradients [3 x 1]
%     e     : the last 3 error samples [3 x 1]
%     w     : filter center freq. parameter {-1 1} [1 x 1]
%     s     : filter bandwidth parameter {0 1} [1 x 1]
%     mu_w  : adaptation constant for w [1x1]
%     mu_s  : adaptation constant for s [1x1]
%     w_lim : [w_min w_max]; min. & max. bounds for w 
%     s_lim : [s_min s_max]; min. & max. bounds for s
%
% Output Parameters:
%     y     : updated output buffer 
%     a     : updated t-gradient buffer 
%     b     : updated s-gradient buffer 
%     e     : updated error buffer 
%     s     : updated filter BW parameters 
%     w     : updated filter CF parameters
%
% SEE ALSO INIT_SOIIR1, ALE_SOIIR1

%       Author : John Garas PhD.
%       Version 2.1, Release October 2002.
%       Copyright (c) DSP ALGORITHMS 2000-2002.

