% [W,y,e,p,xb,w] = asptsovtdlms(xn,xb,W,d,mu,L1,L2,p,b,T)	
%
%    Performs filtering and coefficient update using the 
%    Second Order Volterra Transform Domain Least Mean 
%    Squares Adaptive algorithm. Filtering and coef. update 
%    of both the linear and non-linear coefficients are 
%    performed in the transform-domain (T).
% 
% Input Parameters [Size]:: 
%    xn  : new input sample [1 x 1]
%    xb  : buffer of input samples [L1 + sum(1:L2) x 1]
%    W   : previous T-domain coef. vector W(n-1) [L1 + sum(1:L2) x 1]
%    d   : desired output d(n) [1 x 1]
%    mu  : adaptation constants [1 x 1]
%    L1  : memory length of linear part of w
%    L2  : memory length of non-linear part of w
%    p   : last estimated power of x p(n-1) [L1 + sum(1:L2) x 1]
%    b   : AR pole for recursive calculation of p
%    T   : The transform to be used {fft|dct|dst|...}
%          user defined transforms are also supported.
%          use transform T and its inverse iT. 
%
% Output parameters::
%    W   : updated T-domain coef. vector
%    y   : filter output y(n)
%    e   : error signal; e(n) = d(n)-y(n)
%    p   : new estimated power of x p(n)
%    xb  : updated buffer of input samples
%    w   : updated t-domain coef. vector w(n), only 
%          calculated if this output argument is given.
%
% SEE ALSO INIT_SOVTDLMS, ASPTTDLMS.

%       Author : John Garas PhD.
%       Version 2.1, Release October 2002.
%       Copyright (c) DSP ALGORITHMS 2000-2002.

