% [w,g,mu,y,e,xb]= asptsovvsslms(xn,xb,w,g,d,mu,L1,L2,roh,ssa,mu_min,mu_max)
%
%    Performs filtering and coefficient update using the 
%    Second Order Volterra Variable Step Size Least Mean 
%    Squares Adaptive algorithm.
% 	
% Input Parameters [size] :: 
%    xn  : new input sample [1 x 1]
%    xb  : buffer of input samples [L1 + sum(1:L2) x 1]
%    w   : vector of filter coefficients w(n-1) [L1 + sum(1:L2) x 1]
%    g   : gradient vector g(n-1) [L1 + sum(1:L2) x 1]
%    d   : desired output d(n) [1 x 1]
%    mu  : step size vector [L1 + sum(1:L2) x 1]
%    L1  : memory length of linear part of w
%    L2  : memory length of non-linear part of w
%    roh    : mu step size [1 x 1]
%    ssa    : if 1, the sign-sign algorithm is used to update mu.
%    mu_min : lower bound for mu [1 x 1]
%    mu_max : higher bound for mu [1 x 1]
% Output parameters ::
%    w   : updated filter coefficients w(n)
%    g   : updated gradient vector g(n)
%    mu  : updated vector of step sizes mu(n)
%    y   : filter output y(n)
%    e   : error signal; e(n) = d(n) - y(n)
%    xb  : updated vector of input samples
%
% SEE ALSO INIT_SOVVSSLMS, ASPTVSSLMS, ASPTMVSSLMS, ASPTVFFRLS.

%       Author : John Garas PhD.
%       Version 2.1, Release October 2002.
%       Copyright (c) DSP ALGORITHMS 2000-2002.

