% [W,y,e,p,w] = aspttdftaf(x,W,d,mu,p,b,T)	
%
%    Performs filtering and coefficient update using the 
%    Transform Domain Fault Tolerant Adaptive Filter (TDFTAF). 
%    TDFTAF contains R redundant coefficients to guarantee that 
%    the filter will recover after the occurrence of a partial 
%    hardware failure during operation.
% 
% Input Parameters [Size]:: 
%    x   : input samples delay line [L+R x 1]
%    W   : previous T-domain coef. vector W(n-1) [L+R x 1]
%    d   : desired output d(n) [1 x 1]
%    mu  : adaptation constant
%    p   : last estimated power of x p(n-1) [L x 1]
%    b   : AR pole for recursive calculation of p
%    T   : The transform to be used {fft|dct|dst|...}
%          user defined transforms are also supported.
%          use transform T and its inverse iT. 
%
% Output parameters::
%    W   : updated T-domain coef. vector
%    y   : filter output y(n)
%    e   : error signal; e(n) = d(n)-y(n)
%    p   : new estimated power of x p(n)
%    w   : updated t-domain coef. vector w(n), only 
%          calculated if this output argument is given.
%
% SEE ALSO INIT_TDFTAF, ASPTTDLMS

%       Author : John Garas PhD.
%       Version 2.1, Release October 2002.
%       Copyright (c) DSP ALGORITHMS 2000-2002.

