% [w,x,y,d,e,p] = init_adjlms(L,s,se,w0,x0,d0,y0,e0)
%
%     Creates and initializes the variables required for the 
%     Adjoint Least Mean Squares (ADJLMS) Adaptive Filter algorithm
%     for use in Active Noise & Vibration Control (ANVC) applications.
%
%     BLOCK DIAGRAM      
%                                                d(n)
%                                       ----------->-----.
%                                                        |
%                                        y(n)      ys(n) V 
%         x(n) --->.-------------->[ w ]----->[ s ]---->(+)
%                  |                 ^                   |
%                  |                 |                   |e(n)
%                  |                 |   fe(n)           |
%                  '-------------->[LMS]<-----[ se ]--<--'
%
% Input Parameters [size]:: 
%     L  : Adaptive filter length
%     s  : FIR model of the physical secondary path [M x 1]
%     w0 : initial vector of filter coefficients [L x 1]
%     x0 : initial vector of input samples [L+M-1]
%     d0 : initial desired sample [1 x 1]
%     y0 : vector of filter output samples [M x 1]
%     e0 : initial error vector [N x 1]
%
% Output parameters [default]::
%     w  : Initialized filter coefficients [zeros]
%     x  : Initialized input vector [white noise]
%     y  : Initial vector of filter output samples
%     d  : Initialized desired sample [white noise]
%     e  : Initialized error vector
%     p  : Initialized input vector power
%
% SEE ALSO ASPTADJLMS, ANVC_ADJLMS

%       Author : John Garas PhD.
%       Version 2.1, Release October 2002.
%       Copyright (c) DSP ALGORITHMS 2000-2002.

