% [k,w,x,b,u,P,d,y,e]=init_arlmsnewt(L,M,k0,w0,x0,b0,u0,P0,d0)
%
%    Creates and initializes the variables required for the 
%    efficient implementation of the LMS-Newton algorithm. 
%    Assumption:  L > 2*M
% 	
% Input Parameters:: 
%    L   : number of adaptive filter coefficients
%    M   : number of autoregressive model coefficients (M << L)
%    k0  : vector of initial lattice predictor coefficients [Mx1]
%    w0  : vector of initial filter coefficients [Lx1]
%    x0  : vector of initial input samples [Lx1]
%    b0  : vector of initial backward prediction errors [Lx1]
%    u0  : vector of initial normalized gradients [Lx1]
%    P0  : initial power of b [(M+1)x1]
%    d0  : initial desired response [1x1]
%
% Output parameters::
%    k   : initialized lattice predictor coefficients [zeros]
%    w   : initialized linear combiner coefficients [zeros]
%    x   : initialized input samples vector [random]
%    b   : initialized backward prediction errors [random]
%    u   : initialized normalized gradient vector [zeros]
%    P   : initialized estimated power of b [b .* b]
%    d   : initialized desired response [random]
%    y   : initialized filter output [w' * x]
%    e   : initialized error signal [e = d - y]
%
% SEE ALSO ASPTARLMSNEWT, MODEL_ARLMSNEWT

%       Author : John Garas PhD.
%       Version 2.1, Release October 2002.
%       Copyright (c) DSP ALGORITHMS 2000-2002.

