% [u,w,c,y,e,mu,Px,Pd]=init_eqerr(N,M,u0,w0,y0,d0,mu0)
%
%     Creates and initializes the variables required for the 
%     Equation Error Adaptive Recursive Filter  
%     algorithm. The filter transfer function is given by
%                     A(z)      
%           w(z) = ---------- 
%                   1 - B(z) 
%
%     where A(z) = a_0 + a_1 z^(-1) + ... + a_(N-1) z^(-N+1)
%     and   B(z) =       b_1 z^(-1) + ... + b_M z^(-M)
%
% Input arguments:
%    N     : Number of coefficients of A(z)
%    M     : Number of coefficients of B(z)
%    u0    : [x(0) x(-1) ... x(-N+1) d(0) ... d(-M)]^T 
%    w0    : [a_0 a_1 ... a_(N-1) b_1 ... b_M]^T 
%    y0    : [y(-1) y(-2) ... y(-M)]^T 
%    d0    : desired signal at time index 0
%    mu0   : vector of step sizes 
%
% Output Parameters [default]:
%    u     : initialized composite input [zeros]
%    w     : initialized filter coef. [zeros]
%    y     : initialized filter output vector [zeros]
%    d     : Initialized desired signal [white noise]
%    e     : Initial error signal [e=d-y]
%    mu    : step size vector [.01 ... .01)].
%    Px    : variance of x(n).
%    Pd    : variance of d(n).
%
% SEE ALSO ASPTEQERR, MODEL_EQERR

%       Author : John Garas PhD.
%       Version 2.1, Release October 2002.
%       Copyright (c) DSP ALGORITHMS 2000-2002.

