% [NB,W,w,x,y,d,e,p,NB,S,SE,yF,fxF] = init_fdfxlms(NC,NL,s,se,w0,xn0,d0)
%
%     Creates and initializes the variables required for the 
%     Frequency Domain Filtered-x Least Mean Squares (FDFXLMS) algorithm
%     for use in Active Noise & Vibration Control (ANVC) applications.
%
%     BLOCK DIAGRAM      
%                                                d(n)
%                                       ----------->-----.
%                                                        |
%                                        y(n)      ys(n) V 
%         x(n) --->.-------------->[ w ]----->[ s ]---->(+)
%                  |                 ^                   |
%                  |                 |                   |
%                  |          fx(n)  |          e(n)     |
%                  '-->[ se ]----->[LMS]<--------<-------'
%    
% Input Parameters [size] ::
%     NC   : Required controller length in time domain
%     NL   : new samples per block
%     s    : FIR model of the secondary path in time domain [M x 1]
%     se   : estimate of secondary path in time domain [N x 1]
%     w0   : Initial vector of filter coefficients in time domain [NC x 1]
%     xn0  : Initial input samples block [NL x 1]
%     d0   : Initial primary signal block [NL x 1]
%
% Output parameters [default] ::
%     NB   : FFT length [2.^nextpow2(NC+NL-1)]
%     W    : frequency domain filter coefficients vector [zeros]
%     w    : time domain filter coefficients vector [zeros]
%     x    : overlap-save input vector [zeros]
%     y    : filter output vector in time domain [zeros]
%     d    : primary signal block [zeros]
%     e    : error signal block [e = d + ys]
%     p    : power estimate of fx(n) in freq. domain
%     S    : frequency domain secondary path [fft(s,NB)]
%     SE   : frequency domain estimated secondary path [fft(se,NB)]
%     yF   : output vector buffer [zeros]
%     fxF  : filtered-x buffer [zeros]
%
% SEE ALSO ASPTFDFXLMS, ANVC_FDFXLMS

%       Author : John Garas PhD.
%       Version 2.1, Release October 2002.
%       Copyright (c) DSP ALGORITHMS 2000-2002.

