% [ff,bb,k,cf,c,g,w,x,d,e,y]]=init_ftrls(L,ff0,bb0,k0,cf0,c0,g0,w0,x0,d0)
%
%     Creates and initializes the variables required for the 
%     Fast Transversal Recursive Least Squares algorithm.
% 	
% Input Parameters [Size]:: 
%   L   : Linear combiner length
%   ff0 : initial autocorrelation of forward prediction error [1x1]
%   bb0 : initial autocorrelation of backward prediction error [1x1]
%   k0  : initial normalized gain vector [Lx1]
%   c0  : initial forward predictor coefficients [L+1 x 1]
%   g0  : initial backward predictor coefficients [L+1 x 1]
%   w0  : initial linear combiner coefficients [L x 1]
%   x0  : initial input samples vector [L+1 x 1]
%   d0  : initial desired response [1x1]
%
% Output parameters [Default]::
%   ff  : autocorrelation of forward prediction error [.001]
%   bb  : autocorrelation of backward prediction error [.001]
%   k   : normalized gain vector [ones].
%   c   : forward predictor coefficients [.1*ones(L+1,1)]
%   g   : backward predictor coefficients [.1*ones(L+1,1)]
%   w   : linear combiner coefficients [zeros]
%   x   : input samples vector [zeros]
%   d   : desired output [rand]
%   y   : Linear combiner output [w' * x(1:end-1)]
%   e   : Linear combiner error [d-y]
%
% SEE ALSO ASPTFTRLS, MODEL_FTRLS, ASPTRLSLATTICE.

%       Author : John Garas PhD.
%       Version 2.1, Release October 2002.
%       Copyright (c) DSP ALGORITHMS 2000-2002.

