% [w,x,y,d,e,p,fx] = init_fxlms(L,s,se,w0,x0,d0,y0)
%
%     Creates and initializes the variables required for the 
%     Filtered-x Least Mean Squares (FXLMS) Adaptive Filter algorithm
%     for use in Active Noise & Vibration Control (ANVC) applications.
%
%     BLOCK DIAGRAM      
%                                                d(n)
%                                       ----------->-----.
%                                                        |
%                                        y(n)      ys(n) V 
%         x(n) --->.-------------->[ w ]----->[ s ]---->(+)
%                  |                 ^                   |
%                  |                 |                   |
%                  |         fx(n)   |          e(n)     |
%                  '-->[ se ]----->[LMS]<--------<-------'
%                                 
% Input Parameters [size]:: 
%     L  : Adaptive filter length
%     s  : FIR model of the physical secondary path [M x 1]
%     w0 : initial vector of filter coefficients [L x 1]
%     x0 : initial vector of input samples [max(L,N) x 1]
%     d0 : initial desired sample [1 x 1]
%     y0 : vector of filter output samples [M x 1]
%
% Output parameters [default]::
%     w  : Initialized filter coefficients [zeros]
%     x  : Initialized input delay line [zeros]
%     d  : desired sample [white noise]
%     y  : filter output samples delay line [zeros]
%     e  : error sample
%     p  : Initialized input vector power
%     fx : filtered-x delay line 
%
% SEE ALSO ASPTFXLMS, ANVC_FXLMS, ASPTFDFXLMS, ASPTMCFDFXLMS.

%       Author : John Garas PhD.
%       Version 2.1, Release October 2002.
%       Copyright (c) DSP ALGORITHMS 2000-2002.

