% [w,x,y,d,e,p] = init_mcadjlms(L,Nref,Nact,Nsens,s,se,w0,x0,d0,y0,e0)
%
%     Creates and initializes the variables required for the 
%     Multi-channel Adjoint LMS (MCADJLMS) algorithm
%     for use in Active Noise & Vibration Control (ANVC) applications.
%
%     BLOCK DIAGRAM      
%                                                d(n)
%                                       ----------->-----.
%                                                        |
%            Nref                        y(n)      ys(n) V 
%      x(n) --/--->.-------------->[ w ]--/-->[ s ]---->(+)
%                  |                 ^   Nact            |
%                  |                 |                   |e(n)
%                  |                 |   fe(n)           |
%                  '-------------->[LMS]<-----[ se ]<-/--'
%                                                     Nsens
% Input Parameters:: 
%     L     : Adaptive filter length
%     Nref  : number of reference signals
%     Nact  : number of actuators
%     Nsens : number of sensors
%     s     : FIR model of the secondary path [M x Nact x Nsens]
%     se    : estimate of the secondary path [N x Nact x Nsens]
%     w0    : initial vector of filter coefficients [L x Nref x Nact]
%     x0    : initial vector of input samples [L+N-1 x Nref]
%     d0    : initial desired sample [1 x Nsens]
%     y0    : vector of filter output samples [M x Nsens]
%     e0    : initial error vector [N x Nsens]
%
% Output parameters [default]::
%     w     : Initialized filter coefficients [zeros]
%     x     : Initialized input vector [white noise]
%     y     : Initial vector of filter output samples
%     d     : Initialized desired sample [white noise]
%     e     : Initialized error vector
%     p     : Initialized input vector variance
%
% SEE ALSO ASPTMCADJLMS, ANVC_MCADJLMS

%       Author : John Garas PhD.
%       Version 2.1, Release October 2002.
%       Copyright (c) DSP ALGORITHMS 2000-2002.

