% [NB,W,w,x,y,d,e,p,S,SE,yF,fxF] = init_mcfdfxlms(NC,NL,Nref,Nact,Nsens,s,se,w0,xn0,d0)
%
%     Creates and initializes the variables required for the 
%     Multi-channel Frequency Domain Filtered-x LMS (MCFDFXLMS) algorithm
%     for use in Active Noise & Vibration Control (ANVC) applications.
%
%     BLOCK DIAGRAM      
%                                        Nsens    d(n)
%                                       -----/----->-----.
%                                                        |
%            Nref                        y(n)      ys(n) V 
%      x(n) --/--->.-------------->[ w ]--/-->[ s ]---->(+)
%                  |                 ^   Nact            |
%                  |                 |                   |e(n)
%                  |           fx(n) |                   |
%                  '-----[ se ]--->[LMS]<---------/------'
%                                               Nsens
%
% Input Parameters [size] ::
%     NC    : Required controller length in time domain
%     NL    : new samples per block
%     Nref  : number of reference signals
%     Nact  : number of actuators
%     Nsens : number of sensors
%     s     : FIR model of the secondary paths [M x Nact x Nsens]
%     se    : estimate of secondary paths [N x Nact x Nsens]
%     w0    : Initial time domain matrix of filter coef. [NC x Nref x Nact]
%     xn0   : Initial input samples block [NL x Nref]
%     d0    : Initial primary signals block [NL x Nsens]
%
% Output parameters [default] ::
%     NB   : FFT length [2.^nextpow2(NC+NL-1)]
%     W    : frequency domain filter coefficients matrix [zeros]
%     w    : time domain filter coefficients matrix [zeros]
%     x    : overlap-save input matrix [zeros]
%     y    : filter output matrix in time domain [zeros]
%     d    : primary signals block [zeros]
%     e    : error signals block [e = d + ys]
%     p    : power estimate of fx(n) in freq. domain
%     S    : frequency domain secondary paths [fft(s,NB)]
%     SE   : frequency domain estimated secondary paths [fft(se,NB)]
%     yF   : output matrix buffer [zeros] 
%     fxF  : filtered-x matrix buffer [zeros]
%
% SEE ALSO ASPTMCFDFXLMS, ANVC_MCFDFXLMS
% Output parameters ::
%     W     : vector of filter coefficients (f-domain) [NB x Nref x Nact]
%     w     : vector of filter coefficients (t-domain) [NC x Nref x Nact]
%     se    : Estimated secondary path (f-domain) [NB x Nact x Nsens]
%     x     : vector of overlapped input samples (t-domain) [NB x Nref]
%     y     : filter output vector (t-domain) [NL x Nact]
%     d     : desired response (t-domain) [NL x Nsens]
%     e     : error vector (t-domain) [NL x Nsens]
%     p     : estimate of input vector power (f-domain) [NB x Nref x Nact*Nsens]
%     yF    : output vector in freq. domain [NB x Nact]
%     fxF   : filtered-x vector in freq. domain [NB x Nref x Nact*Nsens]

%       Author : John Garas PhD.
%       Version 2.1, Release October 2002.
%       Copyright (c) DSP ALGORITHMS 2000-2002.

