% [w,x,y,e,d,p,fx] = init_mcfxlms(L,Nref,Nact,Nsens,s,se,w0,x0,d0,y0,fx0)
%
%     Creates and initializes the variables required for the 
%     Multichannel Filtered-X Least Mean Squares (MCFXLMS) algorithm
%     (also known as the Multiple Error Filtered-X LMS (MEFXLMS))
%     for use in Active Noise & Vibration Control (ANVC) applications.
%
%     BLOCK DIAGRAM      
%                                                d(n)
%                                       ----------->-----.
%                                                        |
%            Nref                        y(n)      ys(n) V 
%      x(n) --/--->.-------------->[ w ]--/-->[ s ]---->(+)
%                  |                 ^   Nact            |
%                  |                 |                   |e(n)
%                  |                 |   fe(n)           |
%                  '-------------->[LMS]<-----[ se ]<-/--'
%                                                     Nsens
% Input Parameters [size] :: 
%     L     : Adaptive filter length
%     Nref  : number of reference signals
%     Nact  : number of actuators
%     Nsens : number of sensors
%     s     : FIR model of the secondary path [M x Nact x Nsens]
%     se    : estimate of the secondary path [N x Nact x Nsens]
%     w0    : initial vector of filter coefficients [L x Nref x Nact]
%     x0    : initial vector of input samples [max(L,N) x Nref]
%     d0    : initial desired sample [1 x Nsens]
%     y0    : vector of filter output samples [M x Nsens]
%     fx0   : initial filtered input matrix [L x Nact x Nref*Nsens]
%
% Output parameters [default]::
%     w     : Initialized filter coefficients [zeros]
%     x     : Initialized input samples matrix [white noise]
%     y     : Initial matrix of filter output samples
%     d     : Initialized desired samples [white noise]
%     e     : Initialized error vector [e=d+y]
%     p     : Initialized power of x
%     fx    : Initialized filtered input matrix [zeros]
%
% SEE ALSO ASPTMCFXLMS, ANVC_MCFXLMS, ASPTFXLMS, ASPTFDFXLMS, ASPTMCFDFXLMS.

%       Author : John Garas PhD.
%       Version 2.1, Release October 2002.
%       Copyright (c) DSP ALGORITHMS 2000-2002.

