% [u,w,c,y,d,e,mu,Px,Py]=init_outerr(N,M,u0,w0,c0,d0,mu0)
%
%     Creates and initializes the variables required for the 
%     Output Error Adaptive Recursive Filter  
%     algorithm. The filter transfer function is given by
%                     A(z)      
%           w(z) = ---------- 
%                   1 - B(z) 
%
%     where A(z) = a_0 + a_1 z^(-1) + ... + a_(N-1) z^(-N+1)
%     and   B(z) =       b_1 z^(-1) + ... + b_M z^(-M)
%
% Input arguments:
%    N     : Number of coefficients of A(z).
%    M     : Number of coefficients of B(z).
%    u0    : composite input vector [N+M x 1]
%            [x(0)  ... x(-N+1) y(-1) ... y(-M)]^T
%    w0    : [a_0 a_1 ... a_(N-1) b_1 ... b_M]^T
%    c0    : [a_0(0)  ... a_0(-N+1) b_1(0) ... b_1(-M)]^T
%    d0    : initial desired sample
%    mu0   : vector of step sizes
%
% Output Parameters [default]:
%    u     : initialized composite input [zeros]
%    w     : initialized filter coefficients. [zeros]
%    c     : initialized c [zeros]
%    y     : filter output [zeros]
%    d     : Initialized desired signal [white noise]
%    e     : Initial error signal [e=d-y]
%    mu    : step size vector [.01 ... .01)].
%    Px    : variance of x(n).
%    Py    : variance of y(n).
%
% SEE ALSO ASPTOUTERR, MODEL_OUTERR

%       Author : John Garas PhD.
%       Version 2.1, Release October 2002.
%       Copyright (c) DSP ALGORITHMS 2000-2002.

