% [W,x,d,e,y,Px,X,w]=init_pbfdaf(L,M,P,W0,X0,d0)
%
%    Creates and initializes the variables required for the Partitioned 
%    Block Frequency Domain Adaptive Filter (PBFDAF) algorithm. The FFT
%    length B is internally calculated using the equation
%    B= 2 ^ nextpow2(L+M-1)
% 	
% Input Parameters [Size]:: 
%    L  : number of new input samples per block
%    M  : filter partition length (in t-domain)
%    P  : number of partitions (total filter length = P*M)
%    W0 : initial matrix of filter coefficients [B x P]
%    X0 : initial matrix of f-domain input signal [B x P]
%    d0 : initial desired response vector [L x 1]
%
% Output parameters [default]::
%    W  : initialized matrix of filter coefficients. [zeros]
%    x  : initialized overlap-save input buffer  
%    d  : initialized desired response [white noise]
%    e  : initialized error vector in t-domain
%    y  : initialized filter output in t-domain 
%    Px : initialized estimate of the input power (Bx1)
%    X  : initialized input samples matrix [zeros]
%    w  : time domain filter coefficients vector
%
% SEE ALSO ASPTPBFDAF, ECHO_PBFDAF

%       Author : John Garas PhD.
%       Version 2.1, Release October 2002.
%       Copyright (c) DSP ALGORITHMS 2000-2002.

