% [W,x,d,e,y,Px,X,ci,w]=init_rcpbfdaf(L,M,P,W0,X0,d0)
%
%    Creates and initializes the variables required for the 
%    Reduced Complexity Partitioned Block Frequency Domain 
%    Adaptive Filter (RCPBFDAF) algorithm. The FFT length B 
%    is internally calculated using the equation
%    B= 2 ^ nextpow2(L+M-1) and the G variable below is 
%    given by G = (P-1)*g+1.
% 
% Input Parameters [Size]:: 
%    L  : block length (M = g * L)
%    M  : filter partition length, must be int multiple of L
%    P  : number of partitions (total filter length = P*M)
%    W0 : initial matrix of filter coefficients [B x P]
%    X0 : initial matrix of f-domain input signal [B x G]
%    d0 : initial desired response vector [L x 1]
%
% Output parameters [default]::
%    W  : initialized matrix of filter coefficients. [zeros]
%    x  : initialized overlap-save input buffer  
%    d  : initialized desired response [white noise]
%    e  : initialized error vector in t-domain
%    y  : initialized filter output in t-domain 
%    Px : initialized estimate of the input power (Bx1)
%    X  : initialized input samples matrix [zeros]
%    ci : index of the next partition to be constrained 
%    w  : time domain filter coefficients vector
%
% SEE ALSO ASPTRCPBFDAF, ECHO_RCPBFDAF, ASPTPBFDAF, ASPTBFDAF

%       Author : John Garas PhD.
%       Version 2.1, Release October 2002.
%       Copyright (c) DSP ALGORITHMS 2000-2002.

