% [ff,bb,fb,cf,b,y,e,kf,kb,x] = init_rlslbpef(L,ff0,bb0,fb0,cf0,b0,x0)
%
%     Creates and initializes the variables required for the 
%     Recursive Least Squares Lattice Backward Predictor Error filter. 
% 
% Input Parameters [Size]:: 
%   L   : number of predictor stages 
%   ff0 : initial autocorrelation vector of forward prediction error [Lx1]
%   bb0 : initial autocorrelation vector of backward prediction error [Lx1]
%   fb0 : initial cross-correlation of f and b [Lx1]
%   b0  : initial vector of backward prediction error [L+1 x 1]
%   x0  : initial input delay line [L+1 x 1]
%
% Output parameters [Default]::
%   ff  : autocorrelation vector of forward prediction error [.001*ones(L,1)]
%   bb  : autocorrelation vector of backward prediction error [.001*ones(L,1)]
%   fb  : cross-correlation of f and b [zeros]
%   b   : vector of backward prediction error [zeros]
%   y   : Linear combiner output [zero]
%   e   : Linear combiner error [rand]
%   kf  : forward lattice coefficients [zeros]
%   kb  : backward lattice coefficients [zeros]
%   x   : initialized input delay line [zeros].
%
% SEE ALSO ASPTRLSLBPEF, PREDICT_RLSLBPEF

%       Author : John Garas PhD.
%       Version 2.1, Release October 2002.
%       Copyright (c) DSP ALGORITHMS 2000-2002.

